use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Caleb
Class
Cushing
Dave
Etheridge
Fredric
Howarth
Jesse
Karen
Kent
Load
Luehrs
Mengué
Moore
Olivier
PP
Paul
Rolsky
Shawn
at
autarch
bestpractical
dolmen
doy
ether
irc
kentfredric
lib
paul
sartak
xenoterracide
